@@ -364,7 +364,7 @@ class IPyExperimentsGPU(IPyExperimentsCPU):
         """ for the currently selected GPU device return: total, free and used RAM in bytes """
         self.gpu_clear_cache() # clear cache to report the correct data
         nvml_gpu_id = get_nvml_gpu_id(self.gpu_current_device_id)
-        handle = self.exp.pynvml.nvmlDeviceGetHandleByIndex(nvml_gpu_id)
+        handle = self.pynvml.nvmlDeviceGetHandleByIndex(nvml_gpu_id)
         info   = self.pynvml.nvmlDeviceGetMemoryInfo(handle)
         return info.total, info.free, info.used
 
@@ -400,7 +400,7 @@ class IPyExperimentsPytorch(IPyExperimentsGPU):
         self.gpu_current_device_id = self.torch.cuda.current_device()
 
         # force pytorch to pre-load cuDNN and its kernels to claim unreclaimable memory
-        torch.ones((1, 1)).cuda()
+        torch.ones((1, 1)).to(self.gpu_current_device_id)
 
         # check that all is ready to go, and we get the RAM info
         gpu_ram_total, gpu_ram_free, gpu_ram_used = self.gpu_ram()
